@@ -1,4 +1,4 @@
-// $Id: main_thread.c,v 1.19 2006/05/13 20:57:46 khlut Exp $
+// $Id: main_thread.c,v 1.20 2006/08/23 20:27:52 khlut Exp $
 // Copyright 2005 Elphel, Inc.
 //
 // This file is part of GenReS.
@@ -368,6 +368,7 @@ NPError NPP_New(NPMIMEType mime, NPP instance, uint16 mode, int16 argc,
     pd->mime=strdup(mime);
     pd->stream=0;
     pd->npstream=0;
+    pd->autoclose=0;
     
     run_slave(pd,mime,0);	// run slave parallel process
     
@@ -520,7 +521,7 @@ NPError NPP_DestroyStream(NPP instance, NPStream *stream, NPError reason)
     Debug("%p NPP_DestroyStream %d\n", instance->pdata, reason);
  
     if(Pd->npstream)
-      if(reason != NPRES_DONE) {
+      if(reason != NPRES_DONE || Pd->autoclose) {
 	if(Pd->stream)close(Pd->stream);
 	Pd->stream=0;
       }else {
@@ -612,6 +613,8 @@ void * PR_CALLBACK HandleEvent(ObserveEvent* event)
 	if(strcmp(event->str+2,"CLOSE")==0) {
 	    if(event->pd->stream)close(event->pd->stream);
 	    event->pd->stream=0;
+	}else if(strcmp(event->str+2,"AUTOCLOSE")==0) {
+	    event->pd->autoclose=1;
 	}else if(event->pd->npstream && strcmp(event->str+2,"DESTROY")==0) {
 	    NPStream *stream=event->pd->npstream; event->pd->npstream=0;
 	    NPN.destroystream(event->pd->instance, stream, NPRES_DONE);
