@@ -1,5 +1,5 @@
 #!/usr/bin/perl
-# $Id: mplayer.pl,v 1.31 2006/08/23 20:05:57 khlut Exp $
+# $Id: mplayer.pl,v 1.32 2006/09/04 10:21:29 khlut Exp $
 # Bind mplayer and mencoder with HTML object
 # ElphelOgm is used to receive and record rtp mjpeg video
 #
@@ -36,12 +36,16 @@ $conffile="$ENV{HOME}/.mozilla/genres/mplayer.conf";
   out_file=>['%@-%Y-%m-%d_%H-%M-%S.avi', 'file', "Write video to file(s)",
      "%@  in the filename will be replaced to source URL\n"
     ."%Y - year \t%m - month number\t%d - day of month\n"
-    ."%H - hour \t%M - minute  \t%S - second"
+    ."%H - hour \t%M - minute  \t%S - second\n"
+    ."\$n - number of frames in the file\n"
+    ."\$t - timestamp of the last frame"
   ],
   out_file_once=>['%@-%Y-%m-%d_%H-%M-%S.avi', 'file', "Save video to file",
      "%@  in the filename will be replaced to source URL\n"
     ."%Y - year \t%m - month number\t%d - day of month\n"
-    ."%H - hour \t%M - minute  \t%S - second"
+    ."%H - hour \t%M - minute  \t%S - second\n"
+    ."\$n - number of frames in the file\n"
+    ."\$t - timestamp of the last frame"
   ],
   frames=>  [10000, 'text', "Frames per file limit"],
 );
